import qlat_grid.cg as cg

import qlat as q

def save_prop_float(prop, path):
    cg.save_prop_float(prop, path + ".partial")
    q.qrename_info(path + ".partial", path)

def load_prop_float(prop, path):
    # prop need to have the right geo as input
    return cg.load_prop_float(prop, path)



import qlat_grid.cg as cg

import sys

def begin_with_grid(argv = None, size_node_list = None):
    if size_node_list is None:
        size_node_list = []
    if argv is None:
        argv = sys.argv
    return cg.begin_with_grid(argv, size_node_list)

def end_with_grid(is_preserving_cache = False):
    return cg.end_with_grid(is_preserving_cache)



import os
import qlat_grid.init
import qlat as q

def get_qlat_grid_include():
    return os.path.join(os.path.dirname(qlat_grid.init.__file__), 'include')

def get_include_list():
    return [ get_qlat_grid_include(), ] + q.get_include_list()
